compare-meshes
=======

> Compare meshes and polydata for regression testing.

[![compare-meshes version](https://badge.fury.io/py/compare_meshes.svg)](https://pypi.org/project/compare_meshes/)

## Installation

::::{tab-set}

:::{tab-item} System
```shell
pip install compare-meshes
```
:::

:::{tab-item} Browser
In Pyodide, e.g. the [Pyodide REPL](https://pyodide.org/en/stable/console.html) or [JupyterLite](https://jupyterlite.readthedocs.io/en/latest/try/lab),

```python
import micropip
await micropip.install('compare-meshes')
:::

::::

```{toctree}
:hidden:
:maxdepth: 3
:caption: 📖 Reference

apidocs/index.rst
itkwasm docs <https://itkwasm.readthedocs.io/>
```